'''
    Modul geometrija sadrži funkcije za prikaz točaka,
    dužina, pravaca i kružnica u koordinatnom sustavu uz:
           -10 <= x <= 10
           -10 <= y <= 10    
'''

from turtle import *

def koordinatni_sustav():
    '''Koordinatni sustav uz
           -10 <= x <= 10
           -10 <= y <= 10
       Jedinični razmak iznosi 20 piksela
    '''
    reset()
    title('Točke, dužine, pravci, kružnice')
    tracer(False)
    for i in range(4):
        lt(i * 90)
        pencolor('Gray')   
        for i in range(10):
            pensize(2); fd(20); pensize(1)
            pencolor('Silver')
            lt(90); fd(200); bk(400); fd(200); rt(90)
            pencolor('Gray')
        pu(); home(); pd()
    pencolor('Black') 
    pu(); goto(-200, -225); seth(0)                              
    for i in range(-10, 11):                                  
        write(i, align='center', font=('Arial', 8, 'bold'))    
        fd(20)                                                   
    goto(205, -245)                                              
    write('x', align='center', font=('Arial', 10, 'bold'))          
    pu(); goto(-218, -208); seth(90)                             
    for i in range(-10, 11):                                  
        write(i, align='center', font=('Arial', 8, 'bold'))    
        fd(20)                                                   
    goto(-240 , 195)                                             
    write('y', align='center', font=('Arial', 10, 'bold'))          
    tracer(True)   
    ht()

def točka(t, ispis=False):                                           
    '''Funkcija crta točku t = (x, y) gdje je:
          x - racionalni broj iz intervala [-10, 10]
          y - racionalni broj iz intervala [-10, 10]
       uz
          ispis=True   koordinate točke se ispisuju
          ispis=False  koordinate točke se ne ispisuju
        '''                                              
    pu(); goto(t[0] * 20, t[1] * 20)
    dot(6)                                                       
    if ispis:                                                    
        sety(t[1] * 20 + 5)                                        
        ispis = '{0:.2f}, {1:.2f}'.format(t[0], t[1])            
        write(ispis, align='center', font=('Arial', 8, 'normal')) 

def dužina(t0, t1):
    '''Funkcija crta dužinu omeđenu točkama
       t0 = (x0, y0), t1 = (x1, y1)
    '''
    tracer(False)
    pu(); goto(t0[0] * 20, t0[1] * 20)
    pd(); goto(t1[0] * 20, t1[1] * 20)
    tracer(True)

def udaljenost_točaka(t0, t1):
    '''Funkcija vraća udaljenost između točaka
       t0 = (x0, y0) i t1 = (x1, y1)
    '''
    pu()
    goto(t0[0] * 20, t0[1] * 20)
    return distance(t1[0] * 20, t1[1] * 20) / 20

def pravac_kroz_točke(t0, t1):
    '''Funkcija crta pravac kroz točke
       t0 = (x0, y0), t1 = (x1, y1)
    '''
    t0_p = 20 * t0[0], 20 * t0[1]                                     
    t1_p = 20 * t1[0], 20 * t1[1]                                     
    pu(); goto(t0_p); pd()                                        
    seth(towards(t1_p))                                           
    tracer(False)
    while abs(position()[0]) <= 200 and abs(position()[1]) <= 200:
        fd(1)                                                     
    pu(); goto(t0_p); pd()                                        
    while abs(position()[0]) <= 200 and abs(position()[1]) <= 200:
        bk(1)                                                     
    tracer(True)

def pravac(k, l):
    yp = 10 * k + l
    yn = -10 * k + l
    if (yn >= 10 and yp >= 10) or (yn <= -10 and yp <= - 10):
        print('Pravac y = {0}*x + {1} nije vidljiv u ovom koordinatnom sustavu'.format(k, l))
    else:
        pu()
        goto(-200, yn * 20)
        setheading(towards(200, yp * 20))
        tracer(False)
        while position()[0] <= 200:
            if abs(position()[1]) <= 200:
                pd()
            else:
                pu()
            fd(1)
        tracer(True)

def pravac_točkom(x0, y0, k):
    '''Funkcija crta pravac kroz točku t0 = (x0, y0)
       s nagibom k i vraća odsječak na osi y
       q = y0 – k * x0
    '''
    l = y0 - k * x0
    pravac(k, l)

def lin_funkcija(a, b, c):
    '''Funkcija crta pravac zadanog u obliku: a*x + b*y = c '''
    if b != 0:                     
        pravac(-a / b, c / b)
    else:
        pu(); goto(20 * c  /a, -200)
        pd(); sety(200)
       
def kružnica(sr, r):
    '''Funkcija crta kružnicu sa središtem u točki
       sr = (xsr, ysr) i polumjerom r'''
    tracer(False)
    xsr, ysr = sr
    pu(); goto(20 * (xsr + r), 20 * ysr)
    pd(); seth(90)
    for i in range(360):
        if abs(position()[0]) <= 200 and abs(position()[1]) <= 200:
            pd()
        else:
            pu()
        circle(20 * r, 1)
    tracer(True)

if __name__ == '__main__':
    koordinatni_sustav()
