#Prikaz podataka histogramom - program_histogram.py

from turtle import *
from list_dat import iz_datoteke

def obilježja_podataka(podaci):
    '''Funkcija obavlja pripremu za prikaz histograma podataka određenih listom
       podatci. Korisnik na temelju ispisa najmanje i najveće vrijednosti u
       podatcima utipkavanjem određuje donju i gornju granicu prikaza te broj
       intervala u koje će podatci biti razvrstani.
       Funkcija vraća:
          xmin - donju granicu prikaza
          xmakx - gornju granicu prikaza
          n - broj intervala u koje su podatci razvrstani
          hist - listu broja podataka (frekvenciju) po svakom intrvalu.
    '''
    minimum = min(podatci)
    maksimum = max(podatci)
    broj = len(podatci)
    print('Niz od {} podat(a)ka:\n{}\nima\nminimum = {}\nmaksimum = {}'\
          .format(broj, podatci, minimum, maksimum))
    xmin = int(input('Upisati donju granicu prikaza xmin = '))
    xmaks = int(input('Upisati gornju granica prikaza xmaks = '))
    print('Odabrati broj intervala n tako bude (xmaks - xmin) % n == 0')   
    n = int(input('Broj intervala n = '))                                  #1
    dx = (xmaks - xmin) // n
    hist = []
    for i in range(n):                             
        br = 0
        for j in range(broj):
            if xmin + i * dx <= podatci[j] and podatci[j] < xmin + (i+1) * dx:
                br += 1
        hist.append(br)
    print('\nIspis frekvencija po intervalima:')
    print(' interval    frekvencija')
    for i in range(n):
        print('[{},{})         {}'\
              .format(xmin + i * dx, xmin + (i + 1) * dx, hist[i]))
    return xmin, xmaks, n, hist

def histogram(xmin, xmaks, n, hist, korak=40):                                       #15
    '''Funkcija crta dio brojevnog pravca [xmin, xmaks] podijeljen
       na n jednakih dijelova širine korak s opcijskom vrijednošću
       korak=40. 
       Argument hist je lista koja sadrži broj podataka (frekvenciju)
       koji se nalazi u pojedinom intervalu.
       Predviđeno je da frekvencija pojedinog intervala ne pralazi 10
       tako da je vertikalna os podijeljena na 10 dijelova.
    '''
    reset()
    tracer(0)
    title('Histogram')
    pu(); goto(-200, -100), seth(0); pd(); ht()                       
    for i in range(n):                    
        pd(); pensize(2); fd(korak); pensize(1)
        lt(90); fd(4); bk(8); fd(4); rt(90) 
    pensize(2); fd(25); stamp()
    dx = (xmaks - xmin) // n
    oznake = [(xmin + i * dx) for i in range(n + 1)]
    pu(); goto(-200, -125)  
    for i in range(n + 1):
        write(oznake[i], align='center', font=('Aral',9,'bold'))   
        fd(korak)
    pu(); goto(-200, -100); pd(); lt(90)
    for i in range(10):
        pensize(2); fd(20); pensize(1)
        lt(90); fd(4); bk(8); fd(4); rt(90)
    pensize(2); fd(25); stamp()
    pu(); goto(-218, -108); seth(90)                            
    for i in range(0, 11):                                  
        write(i, align='center', font=('Arial',8,'bold'))
        fd(20)                                                   
    goto(-225, 110)                                             
    write('frekvencija', align='right', font=('Arial',10,'bold')) 
    pensize(1)
    fillcolor('Moccasin')
    for i in range(n):                                                  #2                                                                
        pu(); goto(-200 + i * korak, -100); seth(90); pd()
        begin_fill()
        fd(hist[i] * 20); rt(90); fd(korak)
        rt(90); fd(hist[i] * 20)
        end_fill()
    tracer(1)

def prikaz_histograma(podatci):
    '''Funkcija obavlja crtanje histograma'''
    xmin, xmaks, n, hist = obilježja_podataka(podatci)
    histogram(xmin, xmaks, n, hist)
  
if __name__ == '__main__':
    prikaz_histograma(iz_datoteke('visine_ucenika.txt'))                  #39
    
