# Modul s funkcijama za operacije s prirodnim brojevima 
# prirodni_brojevi.py
''' 
   Modul prirodni_brojevi sadrži funkcije 
   za operacije s prirodnim brojevima
'''
def eratosten(n):
    '''Funkcija određuje listu prostih brojeva manjih ili jednakih n.
       Njezino je trajanje izvođenja znatno dulje od izvođenja funkcije
       prosti_brojevi(). Uključena je u ovaj modul zbog povijesnih
       razloga ali i zbog mogućnosti usporedbe tih dviju funkcija.
    '''  
    popis = [i for i in range(2, n + 1)]             
    k = 0                                                               
    while popis[k] ** 2 <= n + 1:
        for j in range(2, n // popis[k] + 1):
            t = popis[k] * j
            if t in popis:
                popis.remove(t)
        k += 1
    return popis


def prost(n):
    '''Funkcija vraća vrijednosti:
          True   ako je broj prost
          False  ako je broj složen
    '''
    d = 2
    while d ** 2 <= n:          	          
        if n % d == 0:
            return False
        d += 1
    return True

def prosti_brojevi(n):
    '''Funkcija vraća listu prostih brojeva manjih ili jednakih n'''
    return  [i for i in range(2, n + 1) if prost(i)]

def djelitelji(n):
    '''Funkcija vraća listu svih djelitelja broja n'''
    djel = []
    for d in range(1, n + 1):    
        if n % d == 0:           
            djel.append(d)       
    return djel

def prosti_faktori(n):
    '''Funkcija vraća listu prostih faktore broja n'''
    r = []
    prosti = prosti_brojevi(n)
    i = 0
    while n > 1:
        if n % prosti[i] == 0:
            r.append(prosti[i])
            n //= prosti[i]
        else:
            i += 1
    return r

def zajednički_faktori(m, n):
    '''Funkcija vraća listu zajedničkih prostih faktora brojeva m i n'''
    r = []
    prosti = prosti_brojevi(min(m, n))
    i = 0
    while i < len(prosti):
        if m % prosti[i] == 0 and n % prosti[i] == 0:
            r.append(prosti[i])
            m //= prosti[i]
            n //= prosti[i]
        else:
            i += 1
    return r

def nzd(m, n):
    '''Funkcija vraća najveći zajednički djelitelj brojeva m i n'''
    while n != 0:		
        m = m % n
        m, n = n, m
    return m

def nzv(m, n):
    '''Funkcija vraća najmanji zajednički višekratnik brojeva m i n'''
    return m * n // nzd(m, n)

if __name__ == '__main__':
    m = int(input('Upiši broj m = '))
    n = int(input('Upiši borj n = '))
    print('U intervalu [2, {}] prosti brojevi su: \n{}\n'\
          .format(m, prosti_brojevi(m)))
    print('Djelitelji broja {} su:\n{}\n'.format(m, djelitelji(m)))
    print('Prosti faktori broja {} su:\n{}\n'.format(m, prosti_faktori(m)))
    print('Prosti faktori broja {} su:\n{}\n'.format(n, prosti_faktori(n)))
    print('Zajednički prosti faktori brojeva {} i {} su:\n{}\n'\
          .format(m, n, zajednički_faktori(m, n)))
    print('Najveći zajednički djelitelj brojeva {} i {} je: {}\n'\
          .format(m, n, nzd(m, n)))
    print('Najmanji zajednički višekratnik brojeva {} i {} je: {}'\
          .format(m, n, nzv(m, m)))
